import { defineComponent, h } from 'vue-demi';
import { Inertia, mergeDataIntoQueryString, shouldIntercept, } from '@inertiajs/inertia';
/**
 * Alternate of Inertia Link Component
 *
 * @experimental
 */
const InertiaLink = defineComponent({
    name: 'InertiaLink',
    props: {
        as: {
            type: String,
            default: 'a',
        },
        href: {
            type: String,
            default: '',
        },
        method: {
            type: String,
            default: 'get',
        },
        data: {
            type: Object,
            default: () => { },
        },
        replace: {
            type: Boolean,
            default: false,
        },
        preserveScroll: {
            type: Boolean,
            default: false,
        },
        preserveState: {
            type: Boolean,
            default: false,
        },
        only: {
            type: Array,
            default: () => [],
        },
        headers: {
            type: Object,
            default: () => { },
        },
        errorBag: {
            type: String,
            default: null,
        },
        forceFormData: {
            type: Boolean,
            default: false,
        },
        queryStringArrayFormat: {
            type: String,
            default: 'brackets',
        },
    },
    render() {
        const as = (this.$props.as.toLowerCase() || 'a');
        const method = (this.$props.method.toLocaleLowerCase() || 'get');
        const attrs = this.$attrs;
        const [href, data] = mergeDataIntoQueryString(method, this.$props.href, this.$props.data, this.$props.queryStringArrayFormat);
        if (as === 'a' && method !== 'get') {
            console.warn(`Creating POST/PUT/PATCH/DELETE <a> links is discouraged as it causes "Open Link in New Tab/Window" accessibility issues.\n\nPlease specify a more appropriate element using the "as" attribute. For example:\n\n<inertia-link href="${href}" method="${method}" as="button">...</inertia-link>`);
        }
        return h(as, {
            ...this.$attrs,
            ...(as === 'a' ? { href } : {}),
            onClick: (event) => {
                event.preventDefault();
                if (!shouldIntercept(event)) {
                    return;
                }
                Inertia.visit(href, {
                    method: method,
                    data: data,
                    replace: this.$props.replace,
                    preserveScroll: this.$props.preserveScroll,
                    preserveState: this.$props.preserveState ?? method !== 'get',
                    only: this.$props.only,
                    headers: this.$props.headers,
                    errorBag: this.$props.errorBag,
                    forceFormData: this.$props.forceFormData,
                    onCancelToken: attrs.onCancelToken || (() => undefined),
                    onBefore: attrs.onBefore || (() => undefined),
                    onStart: attrs.onStart || (() => undefined),
                    onProgress: attrs.onProgress || (() => undefined),
                    onFinish: attrs.onFinish || (() => undefined),
                    onCancel: attrs.onCancel || (() => undefined),
                    onSuccess: attrs.onSuccess || (() => undefined),
                    onError: attrs.onError || (() => undefined),
                });
            },
        }, this.$slots.default);
    },
});
const installInertiaLink = (app) => app.component('InertiaLink', InertiaLink);
export { InertiaLink, installInertiaLink as install };
if (typeof window !== 'undefined' && window.Vue) {
    // @ts-ignore
    window.Vue.use(InertiaLink);
}
